Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(130)

Unified Diff: build/android/envsetup_functions.sh

Issue 12310007: Switch all remaining android builders to ninja (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/android/envsetup.sh ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/envsetup_functions.sh
diff --git a/build/android/envsetup_functions.sh b/build/android/envsetup_functions.sh
index 08c3a165ac14922c8ee57d33d7c0d8de3149bfbb..50eb3cc47071dae003abeef2607534d44e7e9eed 100755
--- a/build/android/envsetup_functions.sh
+++ b/build/android/envsetup_functions.sh
@@ -134,8 +134,15 @@ common_vars_defines() {
common_gyp_vars() {
export GYP_DEFINES="${DEFINES}"
- # Set GYP_GENERATORS to make-android if it's currently unset or null.
- export GYP_GENERATORS="${GYP_GENERATORS:-make-android}"
+ # Set GYP_GENERATORS to ninja if it's currently unset or null.
+ if [ -z $GYP_GENERATORS ]; then
+ echo "Defaulting GYP_GENERATORS to ninja."
+ GYP_GENERATORS=ninja
+ elif [ "$GYP_GENERATORS" != "ninja" ]; then
+ echo "Warning: GYP_GENERATORS set to '$GYP_GENERATORS'."
+ echo "Only GYP_GENERATORS=ninja has continuous coverage."
+ fi
+ export GYP_GENERATORS
# Use our All target as the default
export GYP_GENERATOR_FLAGS="${GYP_GENERATOR_FLAGS} default_target=All"
« no previous file with comments | « build/android/envsetup.sh ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698